@@ -68,7 +68,6 @@ class TestArgparseDocs:
 
 
 class TestOptionalsParser:
-
     # TODO: move this to a generic argparse fixture
     @pytest.fixture(autouse=True)
     def __setup_optionals_parser(self):
@@ -132,7 +131,6 @@ class TestOptionalsParser:
 
 
 class TestCsvActionsParser:
-
     # TODO: move this to a generic argparse fixture
     @pytest.fixture(autouse=True)
     def __setup_csv_actions_parser(self):
@@ -286,9 +284,10 @@ class ParseStdinTest(BaseArgparseOptions):
             (["foo", "bar", "baz"], ["foo", "bar", "baz"]),
             (["\nfoo\n", " bar ", "\nbaz"], ["\nfoo", " bar", "\nbaz"]),
         ):
-            with mock.patch("sys.stdin") as stdin, mock.patch(
-                "builtins.open", mock.mock_open()
-            ) as mock_file:
+            with (
+                mock.patch("sys.stdin") as stdin,
+                mock.patch("builtins.open", mock.mock_open()) as mock_file,
+            ):
                 stdin.readlines.return_value = readlines
                 stdin.isatty.return_value = False
                 namespace = self.parser.parse_args(["-"])
